
{% extends 'base.html' %}

{% load i18n %}


{% block content %}
    <div class="container">

        <ul id="products-tabs-list" class="tab-style-1 clearfix">
            <li class="active">
                <a href="{% url 'accounts:profile' %}">
                    <i class="fa fa-user"></i>
                    {% trans 'Мій профіль' %}
                </a>
            </li>
            <li>
                <a href="#latest">
                    <i class="fa fa-list-alt"></i>
                    {% trans 'Мої замовлення' %}
                </a>
            </li>
            <li>
                <a href="#latest">
                    <i class="fa fa-heart"></i>
                    {% trans 'Мій список побажань' %}
                </a>
            </li>
        </ul>

    </div>
{% endblock %}
