
{% extends 'accounts/base-email.html' %}

{% load i18n %}


{% block header %}
    {% trans 'Активація аккаунту в' %} {{ domain }}
{% endblock %}


{% block content %}

    {% trans 'Ви створили обліковий запис на' %} {{ domain }}. <br />
    {% trans 'Ваш логін' %} <b>{{ user.username }}</b>. <br /><br />
    {% trans 'Щоб активувати ваш профіль натисніть тут' %}:
    <a href="{{ activate_url }}">{{ activate_url }}</a> . <br /><br />

    {% trans 'З повагою' %}, <br /> {% trans 'адміністрація сайту' %} {{ domain }}.

{% endblock %}
