
{% extends 'accounts/base-profile.html' %}

{% load i18n widget_tweaks %}


{% block content %}

    {{ block.super }}

    <div class="container">
        <div class="row">
            <div class="col-md-6 col-sm-6 col-xs-12">
                <h2>{% trans 'Видалення профілю' %}</h2>
                <p>{% trans 'Введіть ваш пароль щоб видалити профіль' %}</p>

                <form id="login-form" method="post">

                    {% csrf_token %}

                    {{ form.errors }}
                    {{ form.non_field_errors }}

                    <div class="input-group col-xs-12">
                        {{ form.password.label_tag }}
                        {{ form.password|add_class:"form-control input-lg" }}
                        <div class="help-block">{{ form.password.errors }}</div>
                    </div>

                    <button class="btn btn-custom" type="submit">
                        <i class="fa fa-remove"></i>
                        {% trans 'Видалити профіль' %}
                    </button>

                    <a href="{% url 'accounts:profile' %}" class="btn btn-default pull-right">
                        {% trans 'Відмінити' %}
                    </a>
                </form>
            </div>
        </div>
    </div>

{% endblock %}
