
{% extends 'base.html' %}

{% load i18n widget_tweaks %}


{% block content %}

    <div class="container">

        {% if validlink %}

            <div class="row">
                <div class="col-md-6 col-md-offset-3 col-sm-6 col-sm-offset-3 col-xs-12">
                    <h2>{% trans 'Зміна паролю' %}</h2>
                    <p>{% trans 'Введіть ваш новий пароль два рази щоб ми могли перевірити, що ви ввели його правильно.' %}</p>

                    <form id="login-form" method="post">

                        {% csrf_token %}

                        {{ form.errors }}
                        {{ form.non_field_errors }}

                        <div class="input-group col-xs-12">
                            {{ form.new_password1.label_tag }} *
                            {{ form.new_password1|add_class:"form-control input-lg" }}
                            <div class="help-block">{{ form.new_password1.errors }}</div>
                        </div>

                        <div class="input-group col-xs-12">
                            {{ form.new_password2.label_tag }} *
                            {{ form.new_password2|add_class:"form-control input-lg" }}
                            <div class="help-block">{{ form.new_password2.errors }}</div>
                        </div>

                        <button class="btn btn-block btn-custom-2">
                            <i class="fa fa-check"></i>
                            {% trans 'Змінити мій пароль' %}
                        </button>
                    </form>
                </div>
            </div>
        {% else %}

            <p class="alert alert-warning">
                {% trans "Посилання для відновлення неправильне або можливо вже використане." %}
            </p>

        {% endif %}
    </div>

{% endblock %}
