
{% extends 'accounts/base-profile.html' %}

{% load i18n %}


{% block content %}

    {{ block.super }}

    <div class="container">

        <div class="table-responsive">
            <table class="table table-bordered">
                {% with user=request.user %}
                    <tr>
                        <td>{% trans 'Імʼя' %}</td>
                        <td>{{ user.first_name }}</td>
                    </tr>
                    <tr>
                        <td>{% trans 'Прізвище' %}</td>
                        <td>{{ user.last_name }}</td>
                    </tr>
                    <tr>
                        <td>{% trans 'Email' %}</td>
                        <td>{{ user.email }}</td>
                    </tr>
                    <tr>
                        <td>{% trans 'Дата реєстрації' %}</td>
                        <td>{{ user.date_joined }}</td>
                    </tr>
                    <tr>
                        <td>{% trans 'Адреса' %}</td>
                        <td>{{ user.profile.address }}</td>
                    </tr>
                    <tr>
                        <td>{% trans 'Телефон' %}</td>
                        <td>{{ user.profile.mobile }}</td>
                    </tr>
                {% endwith %}
            </table>

            <a href="{% url 'accounts:profile-change' %}" class="btn btn-custom-2">
                <i class="fa fa-edit"></i>
                {% trans 'Редагувати профіль' %}
            </a>

            <a href="{% url 'accounts:password-change' %}" class="btn btn-custom-2">
                <i class="fa fa-lock"></i>
                {% trans 'Змінити пароль' %}
            </a>

            <a href="{% url 'accounts:profile-remove' %}" class="btn btn-custom pull-right">
                <i class="fa fa-remove"></i>
                {% trans 'Видалити профіль' %}
            </a>
        </div>

    </div>

{% endblock %}
