
{% extends 'base.html' %}

{% load i18n widget_tweaks %}


{% block content %}

    <div class="container">
        <div class="row">
            <div class="col-md-6 col-md-offset-3 col-sm-6 col-sm-offset-3 col-xs-12">
                <h2>{% trans 'Відновлення паролю' %}</h2>
                <p>{% trans 'На Вашу електронну адресу буде надіслано посилання для відновлення паролю' %}</p>

                <form id="login-form" method="post">

                    {% csrf_token %}

                    {{ form.errors }}
                    {{ form.non_field_errors }}

                    <div class="input-group">
                        <span class="input-group-addon">
                            <span class="input-icon input-icon-email"></span>
                            <span class="input-text">{{ form.email.label }} *</span>
                        </span>
                        {{ form.email|add_class:"form-control input-lg" }}
                        <div class="help-block">{{ form.email.errors }}</div>
                    </div>

                    <button class="btn btn-block btn-custom-2">{% trans 'Скинути пароль' %}</button>
                </form>
            </div>
        </div>
    </div>

{% endblock %}
